source("helper.R")
library("ggplot2")
library(gridExtra)
library(cowplot)
library(scales)

emission_raw <- read.csv("../00_data/GHG_USA_total.csv", skip = 1) 
health_fuel_mapping <- read.csv("../00_data/health_fuel_mapping.csv")
source_mapping <- read.csv("../00_data/source_agg.csv")

# reformat health data as wide format for each state


emission_source_species <- emission_raw %>%
  select(region, sector, GHG, technology, X2015:X2050) %>%
  left_join(health_fuel_mapping, by = c("sector", "technology")) %>%
  select(region, sector.1, GHG, fuel, X2015: X2050) %>%
  filter(fuel != "ELEC") %>%
  rename(sector = sector.1) %>%
  group_by(region, sector, GHG, fuel) %>%
  summarise_at(.vars = names(.)[5:12],
               .funs = c(sum="sum")) %>%
  ungroup() %>%
  mutate(source = paste0(sector, "-", fuel)) %>%
  select(region, GHG, source, X2015_sum:X2050_sum) %>%
  gather(year, value, -region, -GHG, -source) %>%
  mutate(year = substr(year, 2, 5)) %>%
  left_join(source_mapping, by = "source") %>%
  select(region, GHG, source_agg, year, value) %>%
  group_by(region, GHG, source_agg, year) %>%
  summarise(value = sum(value)) %>%
  ungroup() %>%
  spread(year, value) %>%
  filter(GHG %in% c("PM2.5", "NOx", "SO2", "NH3")) %>%
  group_by(region, GHG) %>%
  summarise_at(.vars = names(.)[4:11],
               .funs = c(sum="sum")) %>%
  ungroup()


write.csv(emission_source_species, "01e emission species series.csv", row.names = F)






