source("helper.R")
library("ggplot2")
library(gridExtra)
library(cowplot)
library(scales)

health_raw <- read.csv("../00_data/health_USA_total.csv", skip = 1) 
health_fuel_mapping <- read.csv("../00_data/health_fuel_mapping.csv")
source_mapping <- read.csv("../00_data/source_agg.csv")

# reformat health data as wide format for each state

health_total <- health_raw %>%
  select(region, X2015:X2050) %>%
  group_by(region) %>%
  summarise_at(.vars = names(.)[2:9],
               .funs = c(sum="sum")) %>%
  ungroup() %>%
  gather(year, value, -region) %>%
  mutate(year = substr(year, 2, 5))
  

health_source <- health_raw %>%
  select(region, sector, GHG, technology, X2015:X2050) %>%
  left_join(health_fuel_mapping, by = c("sector", "technology")) %>%
  select(region, sector.1, fuel, X2015: X2050) %>%
  filter(fuel != "ELEC") %>%
  rename(sector = sector.1) %>%
  group_by(region, sector, fuel) %>%
  summarise_at(.vars = names(.)[4:11],
               .funs = c(sum="sum")) %>%
  ungroup() %>%
  mutate(source = paste0(sector, "-", fuel)) %>%
  select(region, source, X2015_sum:X2050_sum) %>%
  gather(year, value, -region, -source) %>%
  mutate(year = substr(year, 2, 5)) %>%
  left_join(source_mapping, by = "source") %>%
  select(region, source_agg, year, value) %>%
  group_by(region, source_agg, year) %>%
  summarise(value = sum(value)) %>%
  ungroup() %>%
  left_join(health_total, by = c("region", "year")) %>%
  mutate(share = value.x / value.y) %>%
  select(region, source_agg, year, share) %>%
  spread(year, share)

health_species <- health_raw %>%
  select(region, GHG, X2015:X2050) %>%
  group_by(region, GHG) %>%
  summarise_at(.vars = names(.)[3:10],
               .funs = c(sum="sum")) %>%
  ungroup() %>% 
  gather(year, value, -region, -GHG) %>%
  mutate(GHG = ifelse(GHG != "PM2.5_Mor_Heo", substr(GHG, 1, 3), "PM2.5")) %>%
  mutate(year = substr(year, 2, 5)) %>%
  spread(year, value)
  
health_source_abs <- health_raw %>%
  select(region, sector, GHG, technology, X2015:X2050) %>%
  left_join(health_fuel_mapping, by = c("sector", "technology")) %>%
  select(region, sector.1, fuel, X2015: X2050) %>%
  filter(fuel != "ELEC") %>%
  rename(sector = sector.1) %>%
  group_by(region, sector, fuel) %>%
  summarise_at(.vars = names(.)[4:11],
               .funs = c(sum="sum")) %>%
  ungroup() %>%
  mutate(source = paste0(sector, "-", fuel)) %>%
  select(region, source, X2015_sum:X2050_sum) %>%
  gather(year, value, -region, -source) %>%
  mutate(year = substr(year, 2, 5)) %>%
  left_join(source_mapping, by = "source") %>%
  select(region, source_agg, year, value) %>%
  group_by(region, source_agg, year) %>%
  summarise(value = sum(value)) %>%
  ungroup()  %>%
  spread(year, value)


write.csv(health_source, "01a health source by sector-fuel.csv", row.names = F)
write.csv(health_total, "01b health total time series.csv", row.names = F)
write.csv(health_species, "01c health species series.csv", row.names = F)
write.csv(health_source_abs, "01d health source sector-fuel ABS.csv", row.names = F)





