source("helper.R")
library("ggplot2")
library(gridExtra)
library(cowplot)
library(scales)

health_raw <- read.csv("../00_data/health_USA.csv", skip = 1) 
health_fuel_mapping <- read.csv("../00_data/health_fuel_mapping.csv")
source_mapping <- read.csv("../00_data/source_agg.csv")

# reformat health data as wide format for each state

health_long <- health_raw %>%
  select(region, X2015:X2050) %>%
  group_by(region) %>%
  summarise_at(.vars = names(.)[2:9],
               .funs = c(sum="sum")) %>%
  ungroup() %>%
  gather(year, value, -region) %>%
  mutate(year = substr(year, 2, 5))

health_total <- health_long %>%
  spread(year, value) 

health_2015 <- health_long %>%
  filter(year == "2015")


health_relative <- health_long %>%
  left_join(health_2015, by = "region") %>%
  mutate(pct_change = value.y / value.x - 1) %>%
  select(region, year.x, pct_change) %>%
  rename(year = year.x) %>%
  spread(year, pct_change)



write.csv(health_total, "02a health total by states.csv", row.names = F)
write.csv(health_relative, "02b health relative change by states.csv", row.names = F)


write.csv(health_long, "map/out/USA_health_states.csv", row.names = F)




