# This is originally the master script to creat China square maps with GCAM-China outputs
# Created based on Jill and Haewon's script
# Ryna, Oct. 2018
# Modified to plot US map
# Yang Ou, Nov 2018


# load libraries 
library(Rcpp)
library(magrittr)
library(devtools)
library(dplyr)
library(tidyr)
# library(rgcam)
library(readr)
# library(gcammaptools)
library(ggplot2)
library(RColorBrewer)

# Define directories
data_dir <- paste0("./data")
fig_dir <- paste0("./figure")
fig_map <- paste0("./map")
out_dir <- paste0("./out")


# read mapping files
square_map <- read.csv(paste0(data_dir, "/square_map_usa_new.csv"))
trend_map <- read.csv(paste0(data_dir, "/state_group_mapping.csv"))
# read output files
hlth_raw <- read.csv(paste0(out_dir, '/USA_health_states.csv')) 
  


# line chart by province 
hlth <- hlth_raw %>% 
  group_by(region) %>%
  mutate(scenario = "base") %>%
  mutate(rate = value / value[year == 2015] - 1) %>%
  mutate(rate2 = ifelse(is.na(rate), NA, 0)) %>%
  mutate(base = value[year == 2015] / 1000) %>%
  ungroup %>%
  full_join(square_map, by = "region")  %>%
  left_join(trend_map, by = "region") %>%
  filter(region != "AK" & region != "HI") %>%
  arrange(location) %>%
  mutate(region2 = reorder(region, location)) %>%
  mutate(region_short = substr(region, 1, 2)) %>%
  mutate(region_plot = ifelse(region_short == "BL", "", region_short)) %>%
  replace_na(list(scenario = "base")) -> squaredata


squaredata %>%
  ggplot() +
  geom_rect(aes(fill = base), xmin = -Inf, xmax = Inf, ymin = -Inf, ymax = Inf) +
  scale_fill_distiller(palette = "Blues", direction = 1, na.value = "White", 
                       name = "           PM Mortality cost in 2015 (Billions $)") +
  geom_text(aes(x = 2030, y = 0.5, vjust = 1, label = region_plot), size = 5) +
  geom_line(aes(y = rate, x = year), colour = "black", size = 1) +
  geom_line(aes(y = rate2, x = year), colour = "red", linetype="dashed", size = 0.5) +
  # geom_hline(yintercept = 0, colour = "red", linetype="dashed", size = 0.5) +
  facet_wrap( ~ region2, ncol = 11, scales = "fixed") +
  scale_y_continuous(limits = c(-0.65, 0.5), labels = scales::percent, breaks = c(-0.5, 0, 0.5)) +
  scale_x_continuous(limits = c(2014, 2051), breaks = c(2015, 2050)) +
  theme(legend.position="bottom",
        legend.key.width = unit(2, "cm"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        strip.background = element_blank(),
        strip.text = element_blank(),
        axis.text.x = element_text(size = 15, angle = 90, color = "black", vjust= 0.5),
        axis.text.y = element_text(size = 15, color = "black"),
        axis.title.x = element_blank(),
        axis.title.y = element_blank()) +
  ggsave(paste0("../trend_states_TS.png"), width=10, height=8)







