source("helper.R")
library("ggplot2")
library(gridExtra)
library(cowplot)
library(scales)

health_raw <- read.csv("../00_data/health_USA_total.csv", skip = 1) 
elec_raw <- read.csv("../00_data/elec_input_total.csv", skip = 1) 
indus_raw <- read.csv("../00_data/indus_USA_total.csv", skip = 1) 
trans_raw <- read.csv("../00_data/trans_USA_total.csv", skip = 1) 
build_raw <- read.csv("../00_data/build_USA_total.csv", skip = 1) 
pop_raw <- read.csv("../00_data/pop_USA_total.csv", skip = 4) 
gdp_raw <- read.csv("../00_data/GDP_USA_total.csv", skip = 1) 

health_fuel_mapping <- read.csv("../00_data/health_fuel_mapping.csv")
indus_fuel_mapping <- read.csv("../00_data/indus_fuel_mapping.csv") 
trans_fuel_mapping <- read.csv("../00_data/trans_fuel_mapping.csv") 
build_fuel_mapping <- read.csv("../00_data/build_fuel_mapping.csv") 
# reformat health data as wide format for each state

health_total <- health_raw %>%
  select(region, X2015:X2050) %>%
  group_by(region) %>%
  summarise_at(.vars = names(.)[2:9],
               .funs = c(sum="sum")) %>%
  ungroup() %>%
  gather(year, value, -region) %>%
  mutate(year = substr(year, 2, 5))
  
elec_total <- elec_raw %>%
  filter(sector == "electricity") %>%
  select(region, subsector, X2015:X2050) %>%
  mutate(fuel = ifelse(subsector == "coal", "electricity-coal", "electricity-other")) %>%
  group_by(region, fuel) %>%
  summarise_at(.vars = names(.)[3:10],
               .funs = c(sum="sum")) 
  
indus_total <- indus_raw %>%
  select(region, input, X2015:X2050) %>%
  left_join(indus_fuel_mapping, by = "input") %>%
  mutate(fuel = ifelse(fuel == "liquids", "industry-liquids", 
                       ifelse(fuel == "coal", "industry-coal",
                              "industry-other"))) %>%
  group_by(region, fuel) %>%
  summarise_at(.vars = names(.)[3:10],
               .funs = c(sum="sum"))

trans_total <- trans_raw %>%
  select(region, input, X2015:X2050) %>%
  left_join(trans_fuel_mapping, by = "input") %>%
  mutate(fuel = ifelse(fuel == "liquids", "transportation-liquids", "transportation-other")) %>%
  group_by(region, fuel) %>%
  summarise_at(.vars = names(.)[3:10],
               .funs = c(sum="sum"))

build_total <- build_raw %>%
  select(region, input, X2015:X2050) %>%
  left_join(build_fuel_mapping, by = "input") %>%
  mutate(fuel = ifelse(fuel == "biomass", "building-biomass", "building-other")) %>%
  group_by(region, fuel) %>%
  summarise_at(.vars = names(.)[3:10],
               .funs = c(sum="sum"))


energy_consumption_total <- rbind(elec_total, indus_total, trans_total, build_total) %>%
  group_by(region, fuel) %>%
  summarise_at(.vars = names(.)[3:10],
               .funs = c(sum="sum"))


pop_total <- pop_raw %>%
  filter(year %in% c("2015", "2020", "2025", "2030", "2035", "2040", "2045", "2050")) %>%
  mutate(year = paste0("X", year)) %>%
  mutate(key = "population") %>%
  spread(year, totalPop)


pop_long <- pop_total %>%
  select(-key) %>%
  gather(year, population, -region)

# million 1990$
gdpCap_long <- gdp_raw %>%
  select(Region, X2015:X2050) %>%
  rename(region = Region) %>%
  gather(year, GDP, -region)

gdpCap_total <- left_join(gdpCap_long, pop_long, by = c("region", "year")) %>%
  mutate(PopCap = GDP  /population * 1.81) %>%
  select(region, year, PopCap) %>%
  mutate(key = "GDPcapita") %>%
  spread(year, PopCap)

PopGdpP_total <- rbind(pop_total, gdpCap_total)


write.csv(energy_consumption_total, "03a total energy consumption time series.csv", row.names = F)
write.csv(PopGdpP_total, "03b pop and GDP time series.csv", row.names = F)






