source("helper.R")

health_raw <- read.csv("../00_data/health_USA.csv", skip = 1) 
elec_raw <- read.csv("../00_data/elec_input_USA.csv", skip = 1) 
indus_raw <- read.csv("../00_data/indus_USA.csv", skip = 1) 
trans_raw <- read.csv("../00_data/trans_USA.csv", skip = 1) 
build_raw <- read.csv("../00_data/build_USA.csv", skip = 1) 

pop_raw <- read.csv("../00_data/pop_USA.csv", skip = 4) %>%
  filter(region %!in% c("AK", "HI"))

gdp_raw <- read.csv("../00_data/GDP_USA.csv", skip = 1) 

health_fuel_mapping <- read.csv("../00_data/health_fuel_mapping.csv")
indus_fuel_mapping <- read.csv("../00_data/indus_fuel_mapping.csv") 
trans_fuel_mapping <- read.csv("../00_data/trans_fuel_mapping.csv") 
build_fuel_mapping <- read.csv("../00_data/build_fuel_mapping.csv") 


T1 <- "X2015"
T2 <- "X2050"

# reformat health data as wide format for each state
health_wide <- health_raw %>%
  select(region, sector, GHG, technology, T1, T2) %>%
  left_join(health_fuel_mapping, by = c("sector", "technology")) %>%
  select(region, sector.1, fuel, T1, T2) %>%
  filter(fuel != "ELEC") %>%
  rename(sector = sector.1, "hls_t1" = !!names(.[4]), "hls_t2" = !!names(.[5])) %>%
  group_by(region, sector, fuel) %>%
  summarise(hls_t1 = sum(hls_t1), hls_t2 = sum(hls_t2)) %>%
  ungroup() %>% 
  gather(variable, value, -(region:fuel)) %>%
  unite(temp, sector, fuel, variable) %>%
  spread(temp, value)
  
health_wide[is.na(health_wide)] <- 0 

# reformat elec data as wide format for each state
elec_total <- elec_raw %>%
  filter(sector == "electricity") %>%
  select(region, T1, T2) %>%
  group_by(region) %>%
  summarise(elec_total_t1 = sum(eval(parse(text = T1))), 
            elec_total_t2 = sum(eval(parse(text = T2)))) 

elec_wide <- elec_raw %>%
  filter(sector == "electricity" & subsector %in% c("coal", "gas", "biomass", "refined liquids")) %>%
  select(region, subsector, T1, T2) %>%
  mutate(fuel = ifelse(subsector == "refined liquids", "liquids", 
                       ifelse(subsector == "coal", "coal", 
                              ifelse(subsector == "gas", "gas", "biomass")))) %>%
  select(region, fuel, names(.[3]), names(.[4])) %>%
  group_by(region, fuel) %>%
  summarise(t1 = sum(eval(parse(text = T1))), t2 = sum(eval(parse(text = T2)))) %>%
  ungroup() %>%
  left_join(elec_total, by = c("region")) %>%
  mutate(elec_share_t1 = t1 / elec_total_t1, elec_share_t2 = t2 / elec_total_t2) %>%
  select(region, fuel, elec_share_t1, elec_share_t2) %>%
  gather(variable, value, -(region:fuel)) %>%
  unite(temp, fuel, variable) %>%
  spread(temp, value) %>%
  left_join(elec_total, by = c("region"))

# reformat indus data as wide format for each state
indus_total <- indus_raw %>%
  select(region, T1, T2) %>%
  group_by(region) %>%
  summarise(indus_total_t1 = sum(eval(parse(text = T1))), indus_total_t2 = sum(eval(parse(text = T2)))) 

indus_wide <- indus_raw %>%
  select(region, input, T1, T2) %>%
  left_join(indus_fuel_mapping, by = c("input")) %>%
  select(region, fuel, names(.[3]), names(.[4])) %>%
  filter(fuel != "other") %>%
  left_join(indus_total, by = c("region")) %>%
  rename("t1" = !!names(.[3]), "t2" = !!names(.[4])) %>%
  mutate(indus_share_t1 = t1 / indus_total_t1, indus_share_t2 = t2 / indus_total_t2) %>%
  select(region, fuel, indus_share_t1, indus_share_t2) %>%
  gather(variable, value, -(region:fuel)) %>%
  unite(temp, fuel, variable) %>%
  spread(temp, value) %>%
  left_join(indus_total, by = c("region"))
indus_wide[is.na(indus_wide)] <- 0 

# reformat transporation data as wide format for each state
trans_total <- trans_raw %>%
  select(region, T1, T2) %>%
  group_by(region) %>%
  summarise(trans_total_t1 = sum(eval(parse(text = T1))), trans_total_t2 = sum(eval(parse(text = T2)))) 

trans_wide <- trans_raw %>%
  select(region, input, T1, T2) %>%
  left_join(trans_fuel_mapping, by = c("input")) %>%
  select(region, fuel, names(.[3]), names(.[4])) %>%
  filter(fuel != "other") %>%
  left_join(trans_total, by = c("region")) %>%
  rename("t1" = !!names(.[3]), "t2" = !!names(.[4])) %>%
  mutate(trans_share_t1 = t1 / trans_total_t1, trans_share_t2 = t2 / trans_total_t2) %>%
  select(region, fuel, trans_share_t1, trans_share_t2) %>%
  gather(variable, value, -(region:fuel)) %>%
  unite(temp, fuel, variable) %>%
  spread(temp, value) %>%
  left_join(trans_total, by = c("region"))
trans_wide[is.na(trans_wide)] <- 0 

# reformat building data as wide format for each state
build_total <- build_raw %>%
  select(region, T1, T2) %>%
  group_by(region) %>%
  summarise(build_total_t1 = sum(eval(parse(text = T1))), build_total_t2 = sum(eval(parse(text = T2)))) 

build_wide <- build_raw %>%
  select(region, input, T1, T2) %>%
  left_join(build_fuel_mapping, by = c("input")) %>%
  select(region, fuel, names(.[3]), names(.[4])) %>%
  filter(fuel != "other") %>%
  left_join(build_total, by = c("region")) %>%
  rename("t1" = !!names(.[3]), "t2" = !!names(.[4])) %>%
  mutate(build_share_t1 = t1 / build_total_t1, build_share_t2 = t2 / build_total_t2) %>%
  select(region, fuel, build_share_t1, build_share_t2) %>%
  gather(variable, value, -(region:fuel)) %>%
  unite(temp, fuel, variable) %>%
  spread(temp, value) %>%
  left_join(build_total, by = c("region"))
build_wide[is.na(build_wide)] <- 0 

 
# reformat population data as wide format for each state
pop_wide <- pop_raw %>%
  filter(year %in% c(as.numeric(substr(T1, 2, 5)), as.numeric(substr(T2, 2, 5)))) %>%
  mutate(year = ifelse(year == as.numeric(substr(T1, 2, 5)), "Pop_t1", "Pop_t2")) %>%
  spread(year, totalPop) 

# reformat GDP data as wide format for each state
gdp_wide <- gdp_raw %>%
  select(Region, T1, T2) %>%
  rename(region = Region, "gdp_t1" = !!names(.[2]), "gdp_t2" = !!names(.[3])) 


# reformat GDP per capita data as wide format for each state

combined <- sort(union(levels(pop_wide$region), levels(gdp_wide$region)))

gdpCap_wide <- left_join(mutate(pop_wide, region = factor(region, levels = combined)),
                    mutate(gdp_wide, region = factor(region, levels = combined))) %>%
  mutate(gdpCap_t1 = gdp_t1 / Pop_t1, gdpCap_t2 = gdp_t2 / Pop_t2) %>%
  select(region, gdpCap_t1, gdpCap_t2)


# write out a master table contains all information 
master <- pop_wide %>%
  left_join(gdp_wide, by = "region") %>%
  left_join(gdpCap_wide, by = "region") %>%
  left_join(elec_wide, by = "region") %>%
  left_join(indus_wide, by = "region") %>%
  left_join(trans_wide, by = "region") %>%
  left_join(build_wide, by = "region") %>%
  left_join(health_wide, by = "region") %>%
  filter(region != "DC")


write.csv(master, paste0("LMDI_states_", T1, "_", T2, ".csv"), row.names = F)

