source("helper.R")

T1 <- "X2015"
T2 <- "X2050"
NONGHG <- "SO2"

master_states <- read.csv(paste0("../02b_LMDI_prepare_by_species/LMDI_states_X2015_X2050_", 
                                 NONGHG, "_Mor_Heo.csv"))
master_USA <- read.csv(paste0("../02b_LMDI_prepare_by_species/LMDI_USA_X2015_X2050_", 
                              NONGHG, "_Mor_Heo.csv"))


master <- rbind(master_states, master_USA)

# define a function to calculate logrithmic mean weight
LMW <- function(x, y){
  return((x - y) / (log(x) - log(y)))
}

master[master == 0] <- 1e-25


# prepare logrithmic mean weight
working <- master %>%
  mutate(L_elec_coal     = LMW(electricity_coal_hls_t2,       electricity_coal_hls_t1)) %>%
  mutate(L_elec_gas      = LMW(electricity_gas_hls_t2,        electricity_gas_hls_t1)) %>%
  mutate(L_elec_liquids  = LMW(electricity_liquids_hls_t2,    electricity_liquids_hls_t1)) %>%
  mutate(L_elec_biomass  = LMW(electricity_biomass_hls_t2,    electricity_biomass_hls_t1)) %>%
  mutate(L_indus_coal    = LMW(industry_coal_hls_t2,          industry_coal_hls_t1)) %>%
  mutate(L_indus_gas     = LMW(industry_gas_hls_t2,           industry_gas_hls_t1)) %>%
  mutate(L_indus_liquids = LMW(industry_liquids_hls_t2,       industry_liquids_hls_t1)) %>%
  mutate(L_indus_biomass = LMW(industry_biomass_hls_t2,       industry_biomass_hls_t1)) %>%
  mutate(L_trans_gas     = LMW(transportation_gas_hls_t2,     transportation_gas_hls_t1)) %>%
  mutate(L_trans_liquids = LMW(transportation_liquids_hls_t2, transportation_liquids_hls_t1)) %>%
  mutate(L_build_coal    = LMW(building_coal_hls_t2,          building_coal_hls_t1)) %>%
  mutate(L_build_gas     = LMW(building_gas_hls_t2,           building_gas_hls_t1)) %>%
  mutate(L_build_liquids = LMW(building_liquids_hls_t2,       building_liquids_hls_t1)) %>%
  mutate(L_build_biomass = LMW(building_biomass_hls_t2,       building_biomass_hls_t1)) %>%
  mutate(L_indus_coal = ifelse(is.na(L_indus_coal), 1e-25, L_indus_coal)) %>%
  mutate(L_build_coal = ifelse(is.na(L_build_coal), 1e-25, L_build_coal)) %>%
  # effect of population 
  mutate(M_POP = (L_elec_coal + L_elec_gas + L_elec_liquids + L_elec_biomass 
                  + L_indus_coal + L_indus_gas + L_indus_liquids + L_indus_biomass 
                  + L_trans_gas + L_trans_liquids 
                  + L_build_coal + L_build_gas + L_build_liquids + L_build_biomass) 
         * log(Pop_t2 / Pop_t1)) %>%
  # effect of economic growth 
  mutate(M_GDP = (L_elec_coal + L_elec_gas + L_elec_liquids + L_elec_biomass 
                  + L_indus_coal + L_indus_gas + L_indus_liquids + L_indus_biomass 
                  + L_trans_gas + L_trans_liquids 
                  + L_build_coal + L_build_gas + L_build_liquids + L_build_biomass) 
         * log(gdpCap_t2 / gdpCap_t1)) %>%
  # effect of energy intensity
  mutate(D_ELEC_t1 = elec_total_t1 / gdp_t1) %>%
  mutate(D_ELEC_t2 = elec_total_t2 / gdp_t2) %>%
  mutate(D_INDUS_t1 = indus_total_t1 / gdp_t1) %>%
  mutate(D_INDUS_t2 = indus_total_t2 / gdp_t2) %>%
  mutate(D_TRANS_t1 = trans_total_t1 / gdp_t1) %>%
  mutate(D_TRANS_t2 = trans_total_t2 / gdp_t2) %>%
  mutate(D_BUILD_t1 = build_total_t1 / gdp_t1) %>%
  mutate(D_BUILD_t2 = build_total_t2 / gdp_t2) %>%
  mutate(M_ENERGY_ELEC = (L_elec_coal + L_elec_gas + L_elec_liquids + L_elec_biomass) 
         * log(D_ELEC_t2 / D_ELEC_t1)) %>% 
  mutate(M_ENERGY_INDUS = (L_indus_coal + L_indus_gas + L_indus_liquids + L_indus_biomass) 
         * log(D_INDUS_t2 / D_INDUS_t1)) %>%
  mutate(M_ENERGY_TRANS = (L_trans_gas + L_trans_liquids) 
         * log(D_TRANS_t2 / D_TRANS_t1)) %>%
  mutate(M_ENERGY_BUILD = (L_build_coal + L_build_gas + L_build_liquids + L_build_biomass) 
         * log(D_BUILD_t2 / D_BUILD_t1)) %>%
  mutate(M_ENERGY = M_ENERGY_ELEC + M_ENERGY_INDUS + M_ENERGY_TRANS + M_ENERGY_BUILD) %>%
  
  ## effect of fuel shares
  mutate(M_ELEC_COAL = L_elec_coal * log(coal_elec_share_t2 / coal_elec_share_t1)) %>%
  mutate(M_INDUS_COAL = L_indus_coal * log(coal_indus_share_t2 / coal_indus_share_t1)) %>%
  mutate(M_INDUS_LIQ = L_indus_liquids * log(liquids_indus_share_t2 / liquids_indus_share_t1)) %>%
  mutate(M_TRANS_LIQ = L_trans_liquids * log(liquids_trans_share_t2 / liquids_trans_share_t1)) %>%
  mutate(M_BUILD_BIO = L_build_biomass * log(biomass_build_share_t2 / biomass_build_share_t1)) %>%
  mutate(M_OTHER = L_build_coal * log(coal_build_share_t2 / coal_build_share_t1) 
         + L_elec_gas * log(gas_elec_share_t2 / gas_elec_share_t1) 
         + L_indus_gas * log(gas_indus_share_t2 / gas_indus_share_t1) 
         + L_build_gas * log(gas_build_share_t2 / gas_build_share_t1)
         + L_trans_gas * log(gas_trans_share_t2 / gas_trans_share_t1)
         + L_elec_liquids * log(liquids_elec_share_t2 / liquids_elec_share_t1)
         + L_build_liquids * log(liquids_build_share_t2 / liquids_build_share_t1)
         + L_elec_biomass * log(biomass_elec_share_t2 / biomass_elec_share_t1) 
         + L_indus_biomass * log(biomass_indus_share_t2 / biomass_indus_share_t1)) %>%

  # create mortality intensity variables
  # electric - coal, gas, liquids, biomass
  mutate(D_ELEC_COAL_t2 = electricity_coal_hls_t2 / (elec_total_t2 * coal_elec_share_t2)) %>%
  mutate(D_ELEC_COAL_t1 = electricity_coal_hls_t1 / (elec_total_t1 * coal_elec_share_t1)) %>%
  mutate(D_ELEC_GAS_t2 = electricity_gas_hls_t2 / (elec_total_t2 * gas_elec_share_t2)) %>%
  mutate(D_ELEC_GAS_t1 = electricity_gas_hls_t1 / (elec_total_t1 * gas_elec_share_t1)) %>%
  mutate(D_ELEC_LIQUIDS_t2 = electricity_liquids_hls_t2 / (elec_total_t2 * liquids_elec_share_t2)) %>%
  mutate(D_ELEC_LIQUIDS_t1 = electricity_liquids_hls_t1 / (elec_total_t1 * liquids_elec_share_t1)) %>%
  mutate(D_ELEC_BIO_t2 = electricity_biomass_hls_t2 / (elec_total_t2 * biomass_elec_share_t2)) %>%
  mutate(D_ELEC_BIO_t1 = electricity_biomass_hls_t1 / (elec_total_t1 * biomass_elec_share_t1)) %>%
  # industry - coal, gas, liquids, biomass
  mutate(D_INDUS_COAL_t2 = industry_coal_hls_t2 / (indus_total_t2 * coal_indus_share_t2)) %>%
  mutate(D_INDUS_COAL_t1 = industry_coal_hls_t1 / (indus_total_t1 * coal_indus_share_t1)) %>%
  mutate(D_INDUS_GAS_t2 = industry_gas_hls_t2 / (indus_total_t2 * gas_indus_share_t2)) %>%
  mutate(D_INDUS_GAS_t1 = industry_gas_hls_t1 / (indus_total_t1 * gas_indus_share_t1)) %>%
  mutate(D_INDUS_LIQUIDS_t2 = industry_liquids_hls_t2 / (indus_total_t2 * liquids_indus_share_t2)) %>%
  mutate(D_INDUS_LIQUIDS_t1 = industry_liquids_hls_t1 / (indus_total_t1 * liquids_indus_share_t1)) %>%
  mutate(D_INDUS_BIO_t2 = industry_biomass_hls_t2 / (indus_total_t2 * biomass_indus_share_t2)) %>%
  mutate(D_INDUS_BIO_t1 = industry_biomass_hls_t1 / (indus_total_t1 * biomass_indus_share_t1)) %>%
  # transportation - gas, liquids
  mutate(D_TRANS_GAS_t2 = transportation_gas_hls_t2 / (trans_total_t2 * gas_trans_share_t2)) %>%
  mutate(D_TRANS_GAS_t1 = transportation_gas_hls_t1 / (trans_total_t1 * gas_trans_share_t1)) %>%
  mutate(D_TRANS_LIQUIDS_t2 = transportation_liquids_hls_t2 / (trans_total_t2 * liquids_trans_share_t2)) %>%
  mutate(D_TRANS_LIQUIDS_t1 = transportation_liquids_hls_t1 / (trans_total_t1 * liquids_trans_share_t1)) %>%
  # building - coal, gas, liquids, biomass
  mutate(D_BUILD_COAL_t2 = building_coal_hls_t2 / (build_total_t2 * coal_build_share_t2)) %>%
  mutate(D_BUILD_COAL_t1 = building_coal_hls_t1 / (build_total_t1 * coal_build_share_t1)) %>%
  mutate(D_BUILD_GAS_t2 = building_gas_hls_t2 / (build_total_t2 * gas_build_share_t2)) %>%
  mutate(D_BUILD_GAS_t1 = building_gas_hls_t1 / (build_total_t1 * gas_build_share_t1)) %>%
  mutate(D_BUILD_LIQUIDS_t2 = building_liquids_hls_t2 / (build_total_t2 * liquids_build_share_t2)) %>%
  mutate(D_BUILD_LIQUIDS_t1 = building_liquids_hls_t1 / (build_total_t1 * liquids_build_share_t1)) %>%
  mutate(D_BUILD_BIO_t2 = building_biomass_hls_t2 / (build_total_t2 * biomass_build_share_t2)) %>%
  mutate(D_BUILD_BIO_t1 = building_biomass_hls_t1 / (build_total_t1 * biomass_build_share_t1)) %>%
  # calculations
  mutate(M_PM_ELEC_COAL = L_elec_coal * log(D_ELEC_COAL_t2 / D_ELEC_COAL_t1)) %>%
  mutate(M_PM_INDUS_COAL = L_indus_coal * log(D_INDUS_COAL_t2 / D_INDUS_COAL_t1)) %>%
  mutate(M_PM_INDUS_LIQ = L_indus_liquids * log(D_INDUS_LIQUIDS_t2 / D_INDUS_LIQUIDS_t1)) %>%
  mutate(M_PM_TRANS_LIQ = L_trans_liquids * log(D_TRANS_LIQUIDS_t2 / D_TRANS_LIQUIDS_t1)) %>%
  mutate(M_PM_BUILD_BIO = L_build_biomass * log(D_BUILD_BIO_t2 / D_BUILD_BIO_t1)) %>%
  mutate(M_PM_OTHER = L_build_coal * log(D_BUILD_COAL_t2 / D_BUILD_COAL_t1) 
         + L_elec_gas * log(D_ELEC_GAS_t2 / D_ELEC_GAS_t1)
         + L_indus_gas * log(D_INDUS_GAS_t2 / D_INDUS_GAS_t1)
         + L_trans_gas * log(D_TRANS_GAS_t2 / D_TRANS_GAS_t1)
         + L_build_gas * log(D_BUILD_GAS_t2 / D_BUILD_GAS_t1)
         + L_elec_liquids * log(D_ELEC_LIQUIDS_t2 / D_ELEC_LIQUIDS_t1)
         + L_build_liquids * log(D_BUILD_LIQUIDS_t2 / D_BUILD_LIQUIDS_t1)
         + L_elec_biomass * log(D_ELEC_BIO_t2 / D_ELEC_BIO_t1)
         + L_indus_biomass * log(D_INDUS_BIO_t2 / D_INDUS_BIO_t1)) %>%
  # calculate  total health cost columns
  mutate(M_T1 = electricity_coal_hls_t1 + electricity_gas_hls_t1 
         + electricity_liquids_hls_t1 + electricity_biomass_hls_t1 
         + industry_coal_hls_t1 + industry_gas_hls_t1 
         + industry_liquids_hls_t1 + industry_biomass_hls_t1
         + transportation_liquids_hls_t1 + transportation_gas_hls_t1
         + building_coal_hls_t1 + building_gas_hls_t1 
         + building_liquids_hls_t1 + building_biomass_hls_t1) %>%
  mutate(M_T2 = electricity_coal_hls_t2 + electricity_gas_hls_t2 
         + electricity_liquids_hls_t2 + electricity_biomass_hls_t2 
         + industry_coal_hls_t2 + industry_gas_hls_t2 
         + industry_liquids_hls_t2 + industry_biomass_hls_t2
         + transportation_liquids_hls_t2 + transportation_gas_hls_t2
         + building_coal_hls_t2 + building_gas_hls_t2 
         + building_liquids_hls_t2 + building_biomass_hls_t2)


# # output health intensity data for secondary analysis
# master_health_secondary <- working[, c(2, seq(106,133))]
# write.csv(master_health_secondary, "master_health_secondary.csv", row.names = FALSE)


results <- working %>%
  select(region, M_T1, M_T2, M_POP, M_GDP, M_ENERGY, 
         M_ELEC_COAL, M_INDUS_COAL, M_INDUS_LIQ, M_TRANS_LIQ, M_BUILD_BIO, M_OTHER, 
         M_PM_ELEC_COAL, M_PM_INDUS_COAL, M_PM_INDUS_LIQ, M_PM_TRANS_LIQ, M_PM_BUILD_BIO, M_PM_OTHER) 

write.csv(results, paste0("LMDI_results_", T1,"_", T2, "_", NONGHG, ".csv"), row.names = FALSE)





