source("helper.R")
library("RColorBrewer")
library("ggplot2")
library(ggrepel)
library(gridExtra)
library(cowplot)
library(ggpubr)

master <- read.csv("barchart_master.csv") %>%
  select(region, key, pct)

working_Top3 <- master %>%
  filter(key != "M_total") %>%
  group_by(region) %>%
  mutate(rk = rank(-pct)) %>%
  filter(rk <= 3) %>% 
  arrange(region, rk) %>%
  mutate(rank = ifelse(rk == 1, "1st", ifelse(rk == 2, "2nd", "3rd"))) %>%
  select(region, rank, key) %>%
  spread(rank, key)

working_Bottom3 <- master %>%
  filter(key != "M_total") %>%
  group_by(region) %>%
  mutate(rk = rank(-pct)) %>%
  filter(rk >= 13) %>% 
  arrange(region, rk) %>%
  mutate(rank = ifelse(rk == 15, "1st-down", ifelse(rk == 14, "2nd-down", "3rd-down"))) %>%
  select(region, rank, key) %>%
  spread(rank, key)

state_leading_contributors <- left_join(working_Top3, working_Bottom3, by = "region")

write.csv(state_leading_contributors, "state_leading_contributors.csv", row.names = F)