source("helper.R")
library("RColorBrewer")
library("ggplot2")
library(ggrepel)
library(gridExtra)
library(cowplot)
library(ggpubr)

NONGHG <- "PM2.5"

master <- read.csv(paste0("../03b_LMDI_analysis_by_species/LMDI_results_X2015_X2050_", NONGHG,".csv")) %>%
  mutate(M_total = M_T2 - M_T1)

T1 <- "X2015"
T2 <- "X2050"

factor_group_mapping <- read.csv("factor_group_mapping.csv")

base <- master %>%
  select(region, M_T1, M_T2) %>%
  mutate(code = M_T2 / M_T1) 

percentage <- master[,-1] / master$M_T1 

percentage <- data.frame(percentage) %>%
  mutate(code = M_T2) 


# create both absolute decomposition and relative contribution
master_percentage <- base %>%
  left_join(percentage, by = "code") %>%
  select(-M_T1.x, -M_T1.y, -M_T2.x, -M_T2.y, -code) %>%
  gather(key, pct, -region) 

master_absolute <- master %>%
  select(-M_T1, -M_T2) %>%
  gather(key, value, -region)


working <- left_join(master_absolute, master_percentage, by = c("region", "key")) %>%
  left_join(factor_group_mapping, by = c("key")) %>%
  mutate(value = value/1000) %>%
  mutate(pct_label = paste0(round(100*pct, 1), "%")) %>%
  mutate(pct_label_pos = ifelse(pct >= 0, pct_label, " ")) %>%
  mutate(pct_label_neg = ifelse(pct < 0, pct_label, " "))

write.csv(working, "barchart_master.csv")
  

LMDI_bar_chart <- function (data = working, region_name, label_flag = T){
  x_positions <- rev(c("M_total", "M_POP", "M_GDP", "M_ENERGY", "M_ELEC_COAL", "M_INDUS_COAL", 
                       "M_INDUS_LIQ", "M_TRANS_LIQ", "M_BUILD_BIO", "M_OTHER", "M_PM_ELEC_COAL", 
                       "M_PM_INDUS_COAL", "M_PM_INDUS_LIQ", "M_PM_TRANS_LIQ", "M_PM_BUILD_BIO", 
                       "M_PM_OTHER"))
  
  x_labels <- rev(c("Net", "Population", "GDP per capta", "Energy intensity", 
                    "Fuel shares", "", "", "", "", "", "PM mortality \n intensity", 
                    "", "", "", "", ""))
  
  working_USA <- data %>%
    filter(region == region_name)
  
  p <- ggplot(data = working_USA, aes(x = key, y = pct, fill = group)) +
    geom_bar(stat = "identity", color = "black") +
    coord_flip() +
    geom_vline(xintercept = 15.5, colour = "gray10", linetype="dashed", size = 0.3) + 
    geom_hline(yintercept = 0, colour = "black", size = 0.5) +
    xlab("") +
    ylab("Percentage Changes, %") +
    scale_fill_manual(breaks = rev(c("M_total", "M_POP", "M_GDP", "M_ENERGY", "M_ELEC_COAL", "M_INDUS_COAL", 
                                     "M_INDUS_LIQ", "M_TRANS_LIQ", "M_BUILD_BIO", "M_OTHER", "M_PM_ELEC_COAL", 
                                     "M_PM_INDUS_COAL", "M_PM_INDUS_LIQ", "M_PM_TRANS_LIQ", "M_PM_BUILD_BIO", 
                                     "M_PM_OTHER")),
                      values = brewer.pal(n = 6, name = "Set1")) +
                      # values = c("red", "lightblue", "green", "orange", "pink", "purple")) +
    scale_x_discrete(limits = x_positions, labels = x_labels) + 
    scale_y_continuous(limits = c(-0.55, 0.5), labels = scales::percent, 
                       breaks = c(-0.5, -0.25, 0, 0.25, 0.5)) +
    theme_bw() +
    theme(axis.text.y   = element_text(size=14, colour = "black"),
          axis.text.x   = element_text(size=12, colour = "black"),
          axis.title.y  = element_blank(),
          axis.title.x  = element_text(size=16),
          panel.background = element_blank(),
          panel.grid.major = element_blank(), 
          panel.grid.minor = element_blank(),
          panel.border = element_rect(colour = "black", fill=NA, size=1)
    ) + 
    annotate(geom="text", x=6, y= -0.47, label="EGU Coal",
          color="black", size = 4, fontface = 3) +
    annotate(geom="text", x=5, y= -0.445, label="Industry coal ",
             color="black", size = 4, fontface = 3) +
    annotate(geom="text", x=4, y= -0.46, label="Industry Oil",
             color="black", size = 4, fontface = 3) +
    annotate(geom="text", x=3, y= -0.42, label="Transportation oil",
             color="black", size = 4, fontface = 3) +
    annotate(geom="text", x=2, y= -0.42, label="Building biomass",
             color="black", size = 4, fontface = 3) +
    annotate(geom="text", x=1, y= -0.5, label="Other",
             color="black", size = 4, fontface = 3) +
    annotate(geom="text", x=12, y= -0.47, label="EGU Coal",
             color="black", size = 4, fontface = 3) +
    annotate(geom="text", x=11, y= -0.445, label="Industry coal ",
             color="black", size = 4, fontface = 3) +
    annotate(geom="text", x=10, y= -0.46, label="Industry Oil",
             color="black", size = 4, fontface = 3) +
    annotate(geom="text", x=9, y= -0.42, label="Transportation oil",
             color="black", size = 4, fontface = 3) +
    annotate(geom="text", x=8, y= -0.42, label="Building biomass",
             color="black", size = 4, fontface = 3) +
    annotate(geom="text", x=7, y= -0.5, label="Other",
             color="black", size = 4, fontface = 3)
  
  if(label_flag == T){
    p = p + geom_text(aes(label= pct_label_pos), hjust=-0.2, size = 4) +
      geom_text(aes(label= pct_label_neg), hjust=1.1, size = 4)
  }
  
  return(p)
  
}

p <- LMDI_bar_chart(region_name = "USA", label_flag = T)
png(paste0("LMDI_","USA_", T1, "_", T2, "_", NONGHG, ".png"), width = 2800, height = 2400, res = 400)
par(cex = 2, mar = c(4, 4, 1, 1))
p
dev.off()



# all_regions <- master$region
# 
# for (region in all_regions){
#   p <- LMDI_bar_chart(region_name = region)
#   png(paste0("LMDI_all/LMDI_",region, "_", T1, "_", T2, ".png"), width = 3200, height = 2000, res = 400)
#   par(cex = 2, mar = c(4, 4, 1, 1))
#   print(p)
#   dev.off()
# }


