source("helper.R")
library(ggplot2)
library(ggdendro)
library(ggrepel)
library(gridExtra)
library(cowplot)
library(cluster)    # clustering algorithms
library(factoextra) # clustering visualization
library(dendextend) # for comparing two dendrograms

# states_subregions <- read.csv("states_subregions.csv") %>%
#   select(state, CSAPR, RGGI) %>%
#   rename(region = state)
# 
# kmeans_mapping <- read.csv("kmeans_mapping.csv")

raw <- read.csv("../04_LMDI_result/barchart_master.csv") %>%
  select(region, key, pct) %>%
  spread(key, pct) %>%
  select(region, M_POP, M_GDP, M_ENERGY, everything(), -M_total) %>%
  filter(region != "USA")

rownames(raw) <- raw$region

master <- raw %>%
  select(-region)

# standardize each feature
master_standardized <- data.frame(scale(master))


# ########################################################################
# #### compare each type of method, and find Ward's method is the best
# hc1_comp <- agnes(master_standardized, method = "complete")
# hc1_comp$ac  #0.70
# hc1_aver <- agnes(master_standardized, method = "average")
# hc1_aver$ac  #0.61
# hc1_sing <- agnes(master_standardized, method = "single")
# hc1_sing$ac  #0.50
# hc1_ward <- agnes(master_standardized, method = "ward")
# hc1_ward$ac  #0.84
# ########################################################################

# Dissimilarity matrix
d <- dist(master_standardized, method = "euclidean")

# Hierarchical clustering using Complete Linkage
hc1 <- hclust(d, method = "ward.D2" )

# Plot the obtained dendrogram

fviz_nbclust(master_standardized, FUN = hcut, method = "silhouette")
# Cut tree into 2 groups
sub_grp <- cutree(hc1, k = 2)



fviz_cluster(list(data = master_standardized, cluster = sub_grp))

result <- raw %>%
  mutate(cluster = sub_grp) %>%
  select(region, cluster) 

write.csv(result, "cluster_results.csv", row.names = F)  

ggd1 <- hc1 %>%
  as.dendrogram %>%
  highlight_branches %>%
  set("branches_k_color", k=2) %>% 
  set("labels_col", k=2) %>%
  set("branches_lwd", 1.2) %>%
  set("labels_cex", 1) 


p <- ggplot(ggd1, horiz = TRUE) +
  ylab("Cluster Height") +
  xlab("") +
  scale_fill_manual(values = brewer.pal(n = 6, name = "Set1")) +
  scale_x_continuous(breaks=NULL) +
  theme_bw() +
  theme(axis.text.y   = element_blank(),
        axis.text.x   = element_text(size=20, colour = "black"),
        axis.title.y  = element_blank(),
        axis.title.x  = element_text(size=20),
        panel.background = element_blank(),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1)
  ) 


png(filename = "test_hc.png", width = 4000, height = 4000, res = 400)
par(cex = 3, mar = c(4, 4, 1, 1))
p
dev.off()
