# This is the master script to creat China square maps with GCAM-China outputs
# Created based on Jill and Haewon's script
# Ryna, Oct. 2018

# load libraries 
library(Rcpp)
library(magrittr)
library(devtools)
library(dplyr)
library(tidyr)
library(rgcam)
library(readr)
library(gcammaptools)
library(ggplot2)
library(RColorBrewer)

# Define directories
home_dir <- "D:/GCAM-squared"
src_dir <- paste0(home_dir, "/src")
data_dir <- paste0(home_dir, "/data")
fig_dir <- paste0(home_dir, "/figure")
fig_map <- paste0(fig_dir, "/map")
out_dir <- paste0(home_dir, "/out")


# read mapping files
province_map <- read.csv(paste0(data_dir, "/province_names_mappings.csv"))
square_map <- read.csv(paste0(data_dir, "/map_loc_cn.csv"))

# read output files
co2 <- read.csv(paste0(out_dir, '/Chinacoal_co2.csv'))
gen <- read.csv(paste0(out_dir, '/ChinaCoal_gen.csv'))

# line chart by province 
co2 %>% filter(scenario != "SSP2", year >= 2010) %>%
  group_by(province.name, grid.region, scenario) %>%
  mutate(rate = value / value[year == 2010]) %>%
  mutate(base = value[year == 2010]) %>%
  ungroup %>%
  left_join(province_map %>% select(province, province.name), by = "province.name") %>%
  full_join(square_map, by = "province")  %>%
  arrange(location) %>%
  mutate(province2 = reorder(province, location)) %>%
  replace_na(list(scenario = "AllNewCoal")) -> squaredata

squaredata %>%
  ggplot() +
  geom_rect(aes(fill = base), xmin = -Inf, xmax = Inf, ymin = -Inf, ymax = Inf) +
  scale_fill_distiller(palette = "Blues", direction = 1, na.value = "White", name = "MtCO2 in 2010") +
  scale_color_manual(values = c("AllNewCoal" = "black", "NoNewCoal" = "brown")) +
  geom_text(aes(x = 2030, y = 8, vjust = 1, label = province.name), size = 3) +
  geom_line(aes(y = rate, x = year, color = scenario), size = 1) +
  facet_wrap(~ province2, ncol = 8, scales = "fixed") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        strip.background = element_blank(),
        strip.text = element_blank(),
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),        
        axis.ticks.x=element_blank(),
        axis.ticks.y=element_blank()) +
  ggsave(paste0(fig_map, "/coal_co2_square_map.png"), width=10, height=8)

# line chart China
co2 %>% filter(scenario != "SSP2", year >= 2010) %>%
  group_by(scenario, year) %>%
  summarise(value = sum(value)) %>%
  ungroup %>%
  ggplot() +
  geom_line(aes(y = value, x = year, color = scenario), size = 1) +
  scale_x_continuous(name = "Year", breaks = seq(2010, 2050, 5)) +
  scale_y_continuous(name = "MtCO2", limits = c(0, 5000), breaks = seq(0, 5000, 1000)) +
  scale_color_manual(values = c("AllNewCoal" = "black", "NoNewCoal" = "brown")) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        axis.ticks.x=element_blank(),
        axis.ticks.y=element_blank(),
        legend.position = "none") +
  ggtitle("China") +
  ggsave(paste0(fig_map, "/coal_co2_total.png"), width=4, height=3.5)


# plot_GCAM(map.chn, extent = EXTENT_CHINA)

